.. module:: george

.. _gp:

The GP object
=============

The core element of George is the :class:`GP` object.
All of the available methods and properties are documented here:

.. autoclass:: george.GP
   :inherited-members:
